==> RsCMPX_NrFr1Meas-5.0.80-py3-none-any.whl: RsCMPX_NrFr1Meas/Implementations/NrSubMeas/Srs/Trace/Evm/Current.py <==
from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.ArgSingleSuppressed import ArgSingleSuppressed
from ......Internal.Types import DataType


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CurrentCls:
	"""Current commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("current", core, parent)

	def read(self) -> List[float]:
		"""SCPI: READ:NRSub:MEASurement<Instance>:SRS:TRACe:EVM:CURRent \n
		Snippet: value: List[float] = driver.nrSubMeas.srs.trace.evm.current.read() \n
		No command help available \n
		Suppressed linked return values: reliability \n
			:return: results: No help available"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_bin_or_ascii_float_list_suppressed(f'READ:NRSub:MEASurement<Instance>:SRS:TRACe:EVM:CURRent?', suppressed)
		return response

	def fetch(self) -> List[float]:
		"""SCPI: FETCh:NRSub:MEASurement<Instance>:SRS:TRACe:EVM:CURRent \n
		Snippet: value: List[float] = driver.nrSubMeas.srs.trace.evm.current.fetch() \n
		No command help available \n
		Suppressed linked return values: reliability \n
			:return: results: No help available"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_bin_or_ascii_float_list_suppressed(f'FETCh:NRSub:MEASurement<Instance>:SRS:TRACe:EVM:CURRent?', suppressed)
		return response

==> RsCMPX_NrFr1Meas-5.0.100-py3-none-any.whl: RsCMPX_NrFr1Meas/Implementations/NrSubMeas/Srs/Trace/Evm/Current.py <==
from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.ArgSingleSuppressed import ArgSingleSuppressed
from ......Internal.Types import DataType


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CurrentCls:
	"""Current commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("current", core, parent)

	def read(self) -> List[float]:
		"""SCPI: READ:NRSub:MEASurement<Instance>:SRS:TRACe:EVM:CURRent \n
		Snippet: value: List[float] = driver.nrSubMeas.srs.trace.evm.current.read() \n
		Return the values of the EVM vs subcarrier traces. Each value is averaged over the samples in one subcarrier. The results
		of the current, average and maximum traces can be retrieved. See also 'Squares EVM, Magnitude Error, Phase Error'. \n
		Suppressed linked return values: reliability \n
			:return: results: Comma-separated list of EVM values, one value per subcarrier."""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_bin_or_ascii_float_list_suppressed(f'READ:NRSub:MEASurement<Instance>:SRS:TRACe:EVM:CURRent?', suppressed)
		return response

	def fetch(self) -> List[float]:
		"""SCPI: FETCh:NRSub:MEASurement<Instance>:SRS:TRACe:EVM:CURRent \n
		Snippet: value: List[float] = driver.nrSubMeas.srs.trace.evm.current.fetch() \n
		Return the values of the EVM vs subcarrier traces. Each value is averaged over the samples in one subcarrier. The results
		of the current, average and maximum traces can be retrieved. See also 'Squares EVM, Magnitude Error, Phase Error'. \n
		Suppressed linked return values: reliability \n
			:return: results: Comma-separated list of EVM values, one value per subcarrier."""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_bin_or_ascii_float_list_suppressed(f'FETCh:NRSub:MEASurement<Instance>:SRS:TRACe:EVM:CURRent?', suppressed)
		return response
